pub struct WpAlphaModifierV1 { /* private fields */ }Expand description
surface alpha modifier manager
This interface allows a client to set a factor for the alpha values on a surface, which can be used to offload such operations to the compositor, which can in turn for example offload them to KMS.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
This interface has no events.
Implementations
Sourceimpl WpAlphaModifierV1
impl WpAlphaModifierV1
Sourcepub fn destroy(&self)
pub fn destroy(&self)
destroy the alpha modifier manager object
Destroy the alpha modifier manager. This doesn’t destroy objects created with the manager.
Sourcepub fn get_surface<U, D: 'static>(
&self,
surface: &WlSurface,
qh: &QueueHandle<D>,
udata: U,
) -> WpAlphaModifierSurfaceV1
pub fn get_surface<U, D: 'static>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpAlphaModifierSurfaceV1
create a new alpha modifier surface object
Create a new alpha modifier surface object associated with the given wl_surface. If there is already such an object associated with the wl_surface, the already_constructed error will be raised.